@@ -55,7 +55,7 @@ our $VERSION = '0.04';
 
 =head1 DESCRIPTION
 
-Geo::Coder::Free::OpenAddresses provides an interface to the free geolocation database at http://openadresses.io
+Geo::Coder::Free::OpenAddresses provides an interface to the free geolocation database at L<https://openaddresses.io>
 
 Refer to the source URL for licencing information for these files:
 
@@ -131,6 +131,7 @@ sub geocode {
 	} else {
 		$param{location} = shift;
 	}
+
 	if(my $scantext = $param{'scantext'}) {
 		return if(length($scantext) < 6);
 		# FIXME:  wow this is inefficient
@@ -204,6 +205,12 @@ sub geocode {
 
 	# ::diag($location);
 
+	$location =~ s/,\s+,\s+/, /g;
+
+	if($location =~ /^,\s*(.+)/) {
+		$location = $1;
+	}
+
 	if($location =~ /^(.+),\s*Washington\s*DC,(.+)$/) {
 		$location = "$1, Washington, DC, $2";
 	}
@@ -289,10 +296,12 @@ sub geocode {
 		}
 	} elsif($location =~ /^(.+?)[,\s]+(United States|USA|US)$/i) {
 		# Geo::libpostal isn't installed, fail back to Geo::StreetAddress::US, which is rather buggy
+
 		my $l = $1;
 		$l =~ s/,/ /g;
 		$l =~ s/\s\s+/ /g;
-
+# 
+		# ::diag(__PACKAGE__, ': ', __LINE__, ": $location");
 		# my $ap;
 		# if(($location =~ /USA$/) || ($location =~ /United States$/)) {
 			# $ap = Lingua::EN::AddressParse->new(country => 'US', auto_clean => 1, force_case => 1, force_post_code_flag => 0);
@@ -346,6 +355,24 @@ sub geocode {
 				}
 			}
 		}
+
+		# Hack to find "name, street, town, state, US"
+		my @addr = split(/,\s*/, $location);
+		if(scalar(@addr) == 5) {
+			# ::diag(__PACKAGE__, ': ', __LINE__, ": $location");
+			$state = $addr[3];
+			if(length($state) > 2) {
+				if(my $twoletterstate = Locale::US->new()->{state2code}{uc($state)}) {
+					$state = $twoletterstate;
+				}
+			}
+			if(length($state) == 2) {
+				if(my $rc = $self->_get($addr[0] . $addr[1] . $addr[2] . $state . 'US')) {
+					# ::diag(Data::Dumper->new([$rc])->Dump());
+					return $rc;
+				}
+			}
+		}
 	}
 
 	if($location =~ /(.+),\s*([\s\w]+),\s*([\w\s]+)$/) {
@@ -745,7 +772,9 @@ sub _normalize {
 	}
 
 	# Most likely failure of Geo::StreetAddress::US, but warn anyway, just in case
-	warn $self->{'location'}, ": add type $type";
+	if($ENV{AUTHOR_TESTING}) {
+		warn $self->{'location'}, ": add type $type";
+	}
 }
 
 =head2 reverse_geocode
